@@ -13,6 +13,12 @@ from ._constant import Default
 from .error import InvalidFilePathError
 
 
+try:
+    import simplejson as json
+except ImportError:
+    import json  # type: ignore # noqa
+
+
 def get_file_encoding(file_path, encoding):
     from mbstrdecoder import detect_file_encoding
 
@@ -40,14 +46,14 @@ def make_temp_file_path_from_url(temp_dir_path, url):
         raise InvalidFilePathError("url must be a string")
 
     if typepy.is_null_string(url_path):
-        raise InvalidFilePathError("invalid URL path: {}".format(url_path))
+        raise InvalidFilePathError(f"invalid URL path: {url_path}")
 
     temp_name = os.path.basename(url_path.rstrip("/"))
     if typepy.is_null_string(temp_name):
         temp_name = pathvalidate.replace_symbol(temp_name, replacement_text="_")
 
     if typepy.is_null_string(temp_name):
-        raise InvalidFilePathError("invalid URL: {}".format(url))
+        raise InvalidFilePathError(f"invalid URL: {url}")
 
     try:
         return posixpath.join(temp_dir_path, temp_name)
